@@ -15,6 +15,8 @@ class INode(ILocation, IFullMapping):
     
     root = Attribute(u"Root node")
     
+    index = Attribute(u"The tree node index")
+    
     def node(uuid):
         """Return node by uuid located anywhere in this nodetree.
         """
@@ -43,16 +45,4 @@ class INode(ILocation, IFullMapping):
     
     def printtree():
         """Debugging helper.
-        """
-
-_RAISE_KEYERROR = object()
-
-class INodeTraverser(Interface):
-    """Same interface as zope.traversing.interfaces.ITraverser.
-    
-    Changed due to huge dependency tail of zope.traversing.
-    """
-
-    def traverse(path, default=_RAISE_KEYERROR):
-        """Traverse Node(s).
         """
\ No newline at end of file
